"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.FinanceProduct = void 0;
const uuid_1 = require("uuid");
const db_1 = require("../utils/db");
const errors_1 = require("../utils/errors");
class FinanceProduct {
    constructor(obj) {
        if (!obj.financeId || obj.financeId.length > 36) {
            console.log('1 correct');
            throw new errors_1.ValidationError('Wrong financeId value');
        }
        if (!obj.productId || obj.productId.length > 36) {
            console.log('2 correct');
            throw new errors_1.ValidationError('Wrong productId value');
        }
        if (!obj.startDate) {
            console.log('3 correct');
            throw new errors_1.ValidationError('Wrong startDate value');
        }
        if (obj.resources < 0 || obj.resources > 99999999999) {
            console.log('4 correct');
            throw new errors_1.ValidationError('Wrong startDate value');
        }
        this.id = obj.id;
        this.financeId = obj.financeId;
        this.productId = obj.productId;
        this.startDate = obj.startDate;
        this.resources = obj.resources;
    }
    static getOne(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const [result] = yield db_1.pool.execute('SELECT * FROM `finance_product` WHERE `id`=:id', {
                id,
            });
            return result.length === 0 ? null : new FinanceProduct(result[0]);
        });
    }
    static getAllOfUser(financeId) {
        return __awaiter(this, void 0, void 0, function* () {
            const [result] = yield db_1.pool.execute('SELECT * FROM `finance_product` WHERE `financeId`=:financeId', {
                financeId,
            });
            return result.length === 0 ? [] : result.map(obj => new FinanceProduct(obj));
        });
    }
    ;
    add() {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.id) {
                this.id = (0, uuid_1.v4)();
            }
            yield db_1.pool.execute('INSERT INTO `finance_product` (`id`, `financeId`, `productId`, `startDate`, `resources`) VALUES (:id, :financeId, :productId, :startDate, :resources)', {
                id: this.id,
                financeId: this.financeId,
                productId: this.productId,
                startDate: this.startDate,
                resources: this.resources,
            });
            return this.id;
        });
    }
    ;
    static checkIfUsed(productId) {
        return __awaiter(this, void 0, void 0, function* () {
            const [result] = yield db_1.pool.execute('SELECT `financeId` FROM `finance_product` WHERE `productId`=:productId', {
                productId,
            });
            return result;
        });
    }
    ;
    delete() {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute('DELETE FROM `finance_product` WHERE `id`=:id', {
                id: this.id,
            });
            return this.id;
        });
    }
    ;
    static deleteAllOfUser(financeId) {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute('DELETE FROM `finance_product` WHERE `financeId`=:financeId', {
                financeId,
            });
            return true;
        });
    }
    ;
}
exports.FinanceProduct = FinanceProduct;
//# sourceMappingURL=financeProduct.js.map