"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Product = void 0;
const db_1 = require("../utils/db");
const errors_1 = require("../utils/errors");
const uuid_1 = require("uuid");
;
class Product {
    constructor(obj) {
        if (!obj.name || obj.name.length > 50) {
            throw new errors_1.ValidationError('Nie prawidłowa wartość pola "nazwa"');
        }
        if (!obj.annualInterestRate || Number(obj.annualInterestRate) <= 0 || Number(obj.annualInterestRate) > 99.99) {
            throw new errors_1.ValidationError('Nie prawidłowa wartość pola "roczne oprocentowanie"');
        }
        if (!obj.durationInDays || Number(obj.durationInDays) <= 0 || Number(obj.durationInDays) > 99999999999) {
            throw new errors_1.ValidationError('Nie prawidłowa wartość pola "okres trwania"');
        }
        if (Number(obj.minContribution) < 0 || Number(obj.minContribution) > 99999999999) {
            throw new errors_1.ValidationError('Nie prawidłowa wartość pola "minimalny wkład"');
        }
        if (!obj.maxContribution || Number(obj.maxContribution) <= 0 || Number(obj.maxContribution) > 99999999999) {
            throw new errors_1.ValidationError('Nie prawidłowa wartość pola "maksymalny wkład"');
        }
        if (!obj.name || obj.name.length > 300) {
            throw new errors_1.ValidationError('Nie prawidłowa wartość pola "opis"');
        }
        this.id = obj.id;
        this.name = obj.name;
        this.annualInterestRate = obj.annualInterestRate;
        this.durationInDays = obj.durationInDays;
        this.minContribution = obj.minContribution;
        this.maxContribution = obj.maxContribution;
        this.description = obj.description;
    }
    ;
    static getOne(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const [result] = yield db_1.pool.execute('SELECT * FROM `product` WHERE `id`=:id', {
                id,
            });
            return result.length === 0 ? null : new Product(result[0]);
        });
    }
    ;
    static getAll() {
        return __awaiter(this, void 0, void 0, function* () {
            const [result] = yield db_1.pool.execute('SELECT * FROM `product` ORDER BY `annualInterestRate` ASC');
            return result.length === 0 ? null : result.map(obj => new Product(obj));
        });
    }
    ;
    add() {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.id) {
                this.id = (0, uuid_1.v4)();
            }
            ;
            yield db_1.pool.execute('INSERT INTO `product` (id, name, annualInterestRate, durationInDays, minContribution, maxContribution, description) VALUES (:id, :name, :annualInterestRate, :durationInDays, :minContribution, :maxContribution, :description)', {
                id: this.id,
                name: this.name,
                annualInterestRate: this.annualInterestRate,
                durationInDays: this.durationInDays,
                minContribution: this.minContribution,
                maxContribution: this.maxContribution,
                description: this.description
            });
            return this.id;
        });
    }
    ;
    delete() {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute('DELETE FROM `product` WHERE `id`=:id', {
                id: this.id,
            });
            return this.id;
        });
    }
    ;
}
exports.Product = Product;
;
//# sourceMappingURL=product.js.map